var globals_dup =
[
    [ "a", "globals.html", null ],
    [ "c", "globals_c.html", null ],
    [ "f", "globals_f.html", null ],
    [ "h", "globals_h.html", null ],
    [ "i", "globals_i.html", null ],
    [ "m", "globals_m.html", null ],
    [ "o", "globals_o.html", null ],
    [ "p", "globals_p.html", null ],
    [ "q", "globals_q.html", null ],
    [ "r", "globals_r.html", null ],
    [ "s", "globals_s.html", null ],
    [ "t", "globals_t.html", null ]
];